@@ -7,7 +7,7 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed';
 
-our $VERSION   = '0.77_01';
+our $VERSION   = '0.78_01';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -64,44 +64,35 @@ Class::MOP::Module - Module Meta Object
 
 =head1 DESCRIPTION
 
-This is an abstraction of a Perl 5 module, it is a superclass of
-L<Class::MOP::Class>. A module essentially a package with metadata, 
-in our case the version and authority. 
+A module is essentially a L<Class::MOP::Package> with metadata, in our
+case the version and authority.
 
 =head1 INHERITANCE
 
-B<Class::MOP::Module> is a subclass of L<Class::MOP::Package>
+B<Class::MOP::Module> is a subclass of L<Class::MOP::Package>.
 
 =head1 METHODS
 
 =over 4
 
-=item B<meta>
+=item B<< $metamodule->version >>
 
-Returns a metaclass for this package.
+This is a read-only attribute which returns the C<$VERSION> of the
+package, if one exists.
 
-=item B<initialize ($package_name)>
+=item B<< $metamodule->authority >>
 
-This will initialize a Class::MOP::Module instance which represents 
-the module of C<$package_name>.
+This is a read-only attribute which returns the C<$AUTHORITY> of the
+package, if one exists.
 
-=item B<version>
+=item B<< $metamodule->identifier >>
 
-This is a read-only attribute which returns the C<$VERSION> of the 
-package for the given instance.
+This constructs a string which combines the name, version and
+authority.
 
-=item B<authority>
+=item B<< Class::MOP::Module->meta >>
 
-This is a read-only attribute which returns the C<$AUTHORITY> of the 
-package for the given instance.
-
-=item B<identifier>
-
-This constructs a string of the name, version and authority.
-
-=item B<create>
-
-This creates the module; it does not return a useful result.
+This will return a L<Class::MOP::Class> instance for this class.
 
 =back
 
@@ -111,7 +102,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2008 by Infinity Interactive, Inc.
+Copyright 2006-2009 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
